==> dkim-milter-0.6.1.tar.gz: dkim-milter-0.6.1/dkim-filter/dkim-filter.h <==
/*
**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
**	All rights reserved.
**
**  $Id: dkim-filter.h,v 1.45 2007/03/07 15:50:09 msk Exp $
*/

#ifndef _DKIM_FILTER_H_
#define _DKIM_FILTER_H_

#ifndef lint
static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.45 2007/03/07 15:50:09 msk Exp $";
#endif /* !lint */

#define	DKIMF_PRODUCT	"Sendmail DKIM Filter"
#define	DKIMF_VERSION	"0.6.1"

/* libdkim */
#include <dkim.h>

/* make sure we have TRUE and FALSE */
#ifndef FALSE
# define FALSE		0
#endif /* !FALSE */
#ifndef TRUE
# define TRUE		1
#endif /* !TRUE */

/* defaults, limits, etc. */
#define	BUFRSZ		256
#if _FFR_SET_DNS_CALLBACK
#define	CBINTERVAL	3
#endif /* _FFR_SET_DNS_CALLBACK */
#define CMDLINEOPTS	"a:Ab:c:C:d:DfFhi:I:k:Klm:M:op:P:qrRs:S:T:u:U:v:Vx:"
#define	DEFTIMEOUT	5
#define	HOSTUNKNOWN	"unknown-host"
#define	JOBIDUNKNOWN	"(unknown-jobid)"
#define	LOCALHOST	"127.0.0.1"
#define	MAXADDRESS	256
#define	MAXARGV		65536
#define	MAXHDRLEN	78
#define	MAXHEADER	4096
#define	MAXSIGNATURE	1024
#define	TEMPFILE	"/var/tmp/dkXXXXXX"
#define	UNKNOWN		"unknown"

#define AUTHRESULTSHDR	"Authentication-Results"

#define	XHEADERNAME	"X-DKIM"
#define	XSELECTCANONHDR	"X-Canonicalization"

/* POPAUTH db */
#if POPAUTH
# define POPAUTHDB	"/etc/mail/popip.db"
#endif /* POPAUTH */

/*
**  PEER -- peer list, listing clients to ignore
*/

typedef struct Peer * Peer;
struct Peer
{
	char *		peer_info;
	struct Peer *	peer_next;
};

/* externs */
extern char *progname;

#endif /* _DKIM_FILTER_H_ */

==> dkim-milter-0.6.4.tar.gz: dkim-milter-0.6.4/dkim-filter/dkim-filter.h <==
/*
**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
**	All rights reserved.
**
**  $Id: dkim-filter.h,v 1.53 2007/04/16 16:59:40 msk Exp $
*/

#ifndef _DKIM_FILTER_H_
#define _DKIM_FILTER_H_

#ifndef lint
static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.53 2007/04/16 16:59:40 msk Exp $";
#endif /* !lint */

#define	DKIMF_PRODUCT	"Sendmail DKIM Filter"
#define	DKIMF_VERSION	"0.6.4"

/* libsm */
#include <sm/gen.h>

/* libdkim */
#include <dkim.h>

/* make sure we have TRUE and FALSE */
#ifndef FALSE
# define FALSE		0
#endif /* !FALSE */
#ifndef TRUE
# define TRUE		1
#endif /* !TRUE */

/* defaults, limits, etc. */
#define	BUFRSZ		256
#if _FFR_SET_DNS_CALLBACK
#define	CBINTERVAL	3
#endif /* _FFR_SET_DNS_CALLBACK */
#define CMDLINEOPTS	"a:Ab:c:C:d:DfFhi:I:k:Klm:M:o:p:P:qrRs:S:T:u:U:v:Vx:"
#define	DEFTIMEOUT	5
#define	HOSTUNKNOWN	"unknown-host"
#define	JOBIDUNKNOWN	"(unknown-jobid)"
#define	LOCALHOST	"127.0.0.1"
#define	MAXADDRESS	256
#define	MAXARGV		65536
#define	MAXHDRLEN	78
#define	MAXHEADER	4096
#define	MAXSIGNATURE	1024
#define	TEMPFILE	"/var/tmp/dkXXXXXX"
#define	UNKNOWN		"unknown"

#define AUTHRESULTSHDR	"Authentication-Results"

#define	XHEADERNAME	"X-DKIM"
#define	XSELECTCANONHDR	"X-Canonicalization"

/* POPAUTH db */
#if POPAUTH
# define POPAUTHDB	"/etc/mail/popip.db"
#endif /* POPAUTH */

/*
**  PEER -- peer list, listing clients to ignore
*/

typedef struct Peer * Peer;
struct Peer
{
	char *		peer_info;
	struct Peer *	peer_next;
};

/* externs */
extern bool dolog;
extern char *progname;

#endif /* _DKIM_FILTER_H_ */
